package com.example.tests;

import static org.junit.Assert.assertTrue;
import static org.junit.Assert.fail;

import java.util.ArrayList;
import java.util.List;
import java.io.File;

import org.apache.commons.io.FileUtils;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.openqa.selenium.By;
import org.openqa.selenium.OutputType;
import org.openqa.selenium.TakesScreenshot;
import org.openqa.selenium.WebDriver;
import org.openqa.selenium.firefox.FirefoxDriver;
import org.openqa.selenium.support.ui.ExpectedConditions;
import org.openqa.selenium.support.ui.WebDriverWait;

import com.relevantcodes.extentreports.DisplayOrder;
import com.relevantcodes.extentreports.ExtentReports;
import com.relevantcodes.extentreports.ExtentTest;
import com.relevantcodes.extentreports.LogStatus;

public class ExtentReportsTest {

	// create the extent report with a file path, to append to the file, and
	// with newest entry first
	ExtentReports extent;

	private WebDriver driver;
	private ArrayList<String> verificationErrors = new ArrayList<String>();

	@Before
	public void setUp() throws Exception {
		driver = new FirefoxDriver();
		// driver.manage().timeouts().implicitlyWait(30, TimeUnit.SECONDS);
		extent = new ExtentReports("C:\\Eclipse Selenium 2\\reports\\extentreport1.html", false);
		extent.config().documentTitle("Test on AJAX and other tests");
		extent.config().reportHeadline("This is the headline");
		extent.config().reportName("The Report Name");
	}

	@Test
	public void testAjaxWaitForElementPresent() throws Exception {
		ExtentTest test = extent.startTest("TestAjaxWaitForElement", "A test of Ajax creating an element");
		driver.get("http://localhost:8080/Web_Project_1/ajaxTest.jsp");
		driver.findElement(By.id("div1")).click();

		// wait for a div within div1 to show up
		WebDriverWait wait = new WebDriverWait(driver, 30);
		wait.until(ExpectedConditions.visibilityOfElementLocated(By.xpath("//div[@id='div1']/div")));
		try {
			
			assertTrue(driver.findElement(By.cssSelector("BODY")).getText()
					.matches("^[\\s\\S]*response from Servletxx[\\s\\S]*$"));
			test.log(LogStatus.PASS, "Step Name", "Test Passed");
		} catch (Error e) {
			test.log(LogStatus.FAIL, "Step Name", "Error in AJAX, AJAX did not build page correctly");
			File src= ((TakesScreenshot)driver).getScreenshotAs(OutputType.FILE);
			FileUtils.copyFile(src, new File("C:\\Eclipse Selenium 2\\reports\\screencast1.png"));
			test.log(LogStatus.INFO, "Snapshot below: " + test.addScreenCapture("C:\\Eclipse Selenium 2\\reports\\screencast1.png"));
			verificationErrors.add(e.toString());
		}
		extent.endTest(test);
	}
	
	@Test
	public void testAjaxWaitForElementPresent1() throws Exception {
		ExtentTest test = extent.startTest("TestAjaxWaitForElement1", "Another test of Ajax creating an element");
		driver.get("http://localhost:8080/Web_Project_1/ajaxTest.jsp");
		driver.findElement(By.id("div1")).click();

		// wait for a div within div1 to show up
		WebDriverWait wait = new WebDriverWait(driver, 30);
		wait.until(ExpectedConditions.visibilityOfElementLocated(By.xpath("//div[@id='div1']/div")));
		try {
			
			assertTrue(driver.findElement(By.cssSelector("BODY")).getText()
					.matches("^[\\s\\S]*response from Servlet[\\s\\S]*$"));
			test.log(LogStatus.PASS, "Step Name", "Test Passed page built correctly");
		} catch (Error e) {
			test.log(LogStatus.FAIL, "Step Name", "Error in AJAX, AJAX did not build page correctly");
			verificationErrors.add(e.toString());
		}
		extent.endTest(test);
	}

	@After
	public void tearDown() throws Exception {
		driver.quit();
		extent.flush();
		for (String verificationErrorString : verificationErrors) {
			if (!"".equals(verificationErrorString)) {
				fail(verificationErrorString);
			}
		}
	}
	

}
